==> portone_mcp_server-0.8.0-py3-none-any.whl: portone_mcp_server/resources/docs/help/pricing/portone/portone-pricing.md <==
---
title: 포트원 요금
category: 이용요금 (수수료·서비스 요금) > 포트원 요금 > 포트원 요금
seo:
  title: 포트원 요금
  description: >-
    각 결제대행사와의 전략적인 제휴로 인하여, 포트원의 관리자콘솔 및 API를 무료로 이용하실 수 있습니다. 포트원을 통해 결제연동 및
    API 사용을 부담없이 시작해보세요.
  keywords:
    - 포트원 요금
    - 포트원 수수료
    - 비용문의
tags:
  - 공통
  - 포트원 요금
pgCompanies:
  - 공통
searchTags:
  - OPI
  - Custom
  - Growth
  - Free
  - 원 페이먼트 인프라
  - 서비스 요금
  - 무료
  - 관리비
  - 가입비
  - 애널리틱스 요금
  - 결제데이터분석 요금
  - 파트너정산 요금
  - 파트너정산자동화 요금
  - 비용
  - 포트원비용
---

## **결제연동 서비스 요금이 무료 ?**

포트원이 추천해드리는 결제대행사 추천패키지를 선택하시면 해당 결제대행사와 계약을 맺으실 때도 가입비 및 연 관리비가 모두 면제 처리 됩니다.

<Callout title="포트원 추천패키지 보러가기 ↗" />

※ 가입비 무료 프로모션 종료 일자 : 2024년 06월 30일 (해당 일자 신청 건 까지 프로모션 적용)

※ 포트원 서비스 요금은 내부 사정에 따라 변동 될 수 있습니다.

<Callout title="결제대행사별 가입비 및 수수료 보러가기 ↗" />

## **포트원의 부가서비스**

### 1. **파트너 정산 자동화**

**매달 반복되는 모든 파트너(하위셀러) 정산을 한 번에 처리하는 원스톱 정산 솔루션입니다.**

- 고정 요금과 서비스 기능별 이용 요금으로 구성되어 있습니다.
- 도입문의를 남겨주시면 상세 요금을 안내해 드리겠습니다.  (**[도입문의 링크](https://go.portone.io/platform-inquiry2)**)

<Callout title="파트너 정산 자동화 연동가이드 보러가기 ↗" />

### **2. 결제 데이터 분석**

**포트원 결제 데이터 분석은 결제 데이터 기반으로 인사이트를 제공하여 고객사가 빠른 의사결정을 할 수 있도록 돕는 결제 데이터 기반 분석 대시보드입니다.**

- 현재 베타 서비스로 제공되며 베타 서비스는 모두 무료입니다.\
  베타 서비스가 종료되고 정식으로 서비스가 런칭되면 유료로 전환됩니다.

<Callout title="결제 데이터 분석 서비스 가이드 보러가기 ↗" />

### **3. 크로스보더**

글로벌 사업 성공을 위한 결제 전략부터 운영 인프라까지 포트원이 맡아드립니다.

- 거래액의 0.5% (최소 월 USD 500) \
  (※이용 요금은 변동 될 수 있습니다)

<Callout title="크로스보더 서비스 가이드 보러가기 ↗" />

### 4. **원 페이먼트 인프라(One Payment Infra)**

- 결제부터 정산까지 단 한 줄의 코드 연동으로 올인원 결제 인프라를 구축할 수 있는 서비스입니다.

* **요금안내**



- One Payment Infra 기능



- **통합관리자 페이지**\
  \- PG통합 관리자 페이지 \
  \- 다양한 PG사의 결제 내역을 한번에 관리 가능 \
  \- 결제 상태 취소와 환불 처리 서비스, 현금영수증 발행 및 관리서비스 제공

* **스마트라우팅**\
  \- ON/OFF  스위치 기능으로 개발자 없이 결제 트래픽 분산 \
  \- 장애 인지 후 10초 이내로 즉각 대응 가능\
  ( 자체 구축은 대응까지 평균 1시간 소요)

- **빌링결제**\
  \- 여러 개 빌링키를 통합 관리 할 수 있는 슈퍼빌링키 제공\
  \- 통합 결제 내역 확인 및 실패 건에 대한 재예약/재시도 등 빌링결제 관리 기능 제공

* **PG거래대사**\
  \- 여러 PG 정산 데이터를 한곳에서 관리 가능\
  \- 주문 정보와 거래 내역(승인, 취소, 환불)일치 여부등 거래대사 가능

- **결제 데이터 분석**\
  \- 결제 트렌드 및 결제 수단 우선순위 등 매출 성과 분석 가능\
  \- 결제 전환율 분석을 통해 개선 인사이트 도출

<Callout title="One Payment Infra 상세내용 보러가기 ↗" />

==> portone_mcp_server-0.9.0-py3-none-any.whl: portone_mcp_server/resources/docs/help/pricing/portone/portone-pricing.md <==
---
title: 포트원 요금
category: 이용요금 (수수료·서비스 요금) > 포트원 요금 > 포트원 요금
seo:
  title: 포트원 요금
  description: >-
    각 결제대행사와의 전략적인 제휴로 인하여, 포트원의 관리자콘솔 및 API를 무료로 이용하실 수 있습니다. 포트원을 통해 결제연동 및
    API 사용을 부담없이 시작해보세요.
  keywords:
    - 포트원 요금
    - 포트원 수수료
    - 비용문의
tags:
  - 공통
  - 포트원 요금
pgCompanies:
  - 공통
searchTags:
  - OPI
  - Custom
  - Growth
  - Free
  - 원 페이먼트 인프라
  - 서비스 요금
  - 관리비
  - 가입비
  - 애널리틱스 요금
  - 결제데이터분석 요금
  - 파트너정산 요금
  - 파트너정산자동화 요금
  - 비용
  - 포트원비용
---

## **결제연동 서비스 요금**

포트원이 추천해드리는 결제대행사 추천패키지를 선택하시면 보다 빠르게 계약이 진행 될 수 있습니다.

<Callout title="포트원 추천패키지 보러가기 ↗" />

- One Payment Infra(원 페이먼트 인프라)서비스



※ 가입비 무료 프로모션 종료 일자 : 2024년 06월 30일 (해당 일자 신청 건 까지 프로모션 적용)

※ 포트원 서비스 요금은 내부 사정에 따라 변동 될 수 있습니다.

※ PG사(결제대행사) 계약시 부가 되는 가입비는 PG사(결제대행사)별로 상이 할 수 있습니다.

<Callout title="결제대행사별 가입비 및 수수료 보러가기 ↗" />

## **포트원의 부가서비스**

### 1. **파트너 정산 자동화**

**매달 반복되는 모든 파트너(하위셀러) 정산을 한 번에 처리하는 원스톱 정산 솔루션입니다.**

- 고정 요금과 서비스 기능별 이용 요금으로 구성되어 있습니다.
- 도입문의를 남겨주시면 상세 요금을 안내해 드리겠습니다.  (**[도입문의 링크](https://go.portone.io/platform-inquiry2)**)

<Callout title="파트너 정산 자동화 연동가이드 보러가기 ↗" />

### **2. 결제 데이터 분석**

**포트원 결제 데이터 분석은 결제 데이터 기반으로 인사이트를 제공하여 고객사가 빠른 의사결정을 할 수 있도록 돕는 결제 데이터 기반 분석 대시보드입니다.**

- 현재 베타 서비스로 제공되며 베타 서비스는 모두 무료입니다.\
  베타 서비스가 종료되고 정식으로 서비스가 런칭되면 유료로 전환됩니다.

<Callout title="결제 데이터 분석 서비스 가이드 보러가기 ↗" />

### **3. 크로스보더**

글로벌 사업 성공을 위한 결제 전략부터 운영 인프라까지 포트원이 맡아드립니다.

- 거래액의 0.5% (최소 월 USD 500) \
  (※이용 요금은 변동 될 수 있습니다)

<Callout title="크로스보더 서비스 가이드 보러가기 ↗" />

### 4. **원 페이먼트 인프라(One Payment Infra)**

- 결제부터 정산까지 단 한 줄의 코드 연동으로 올인원 결제 인프라를 구축할 수 있는 서비스입니다.

* **요금안내**



- One Payment Infra 기능



- **통합관리자 페이지**\
  \- PG통합 관리자 페이지 \
  \- 다양한 PG사의 결제 내역을 한번에 관리 가능 \
  \- 결제 상태 취소와 환불 처리 서비스, 현금영수증 발행 및 관리서비스 제공

* **스마트라우팅**\
  \- ON/OFF  스위치 기능으로 개발자 없이 결제 트래픽 분산 \
  \- 장애 인지 후 10초 이내로 즉각 대응 가능\
  ( 자체 구축은 대응까지 평균 1시간 소요)

- **빌링결제**\
  \- 여러 개 빌링키를 통합 관리 할 수 있는 슈퍼빌링키 제공\
  \- 통합 결제 내역 확인 및 실패 건에 대한 재예약/재시도 등 빌링결제 관리 기능 제공

* **PG거래대사**\
  \- 여러 PG 정산 데이터를 한곳에서 관리 가능\
  \- 주문 정보와 거래 내역(승인, 취소, 환불)일치 여부등 거래대사 가능

- **결제 데이터 분석**\
  \- 결제 트렌드 및 결제 수단 우선순위 등 매출 성과 분석 가능\
  \- 결제 전환율 분석을 통해 개선 인사이트 도출

<Callout title="One Payment Infra 상세내용 보러가기 ↗" />
